OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Propra aktivaĵa fluo por %s",
    "Your feed URL is invalid" : "Via fluo-adreso ne validas",
    "Activity feed for %1$s" : "Aktivaĵa fluo por %1$s",
    "Activity feed" : "Aktivaĵa fluo",
    "Your settings have been updated." : "Viaj agordoj ĝisdatiĝis.",
    "Settings have been updated." : "Agordoj estis ĝisdatigitaj.",
    "Recent activity" : "Lastatempa aktiveco",
    "No activities" : "Neniu aktivaĵo",
    "More activities" : "Pli da aktivecoj",
    "Daily activity summary for %s" : "Taga resumo de aktiveco por %s",
    "_and %n more _::_and %n more _" : ["kaj %n aliaj ","kaj %n aliaj "],
    "All activities" : "Ĉiuj aktivaĵoj",
    "By others" : "De aliuloj",
    "By you" : "De vi",
    "Activity at %s" : "Aktiveco ĉe %s",
    "Hello %s" : "Saluton %s",
    "Hello %s," : "Saluton %s,",
    "There was some activity at %s" : "Okazis kelkaj aktivaĵoj en %s",
    "Mail" : "Retpoŝto",
    "Push" : "Puŝi",
    "Activity" : "Aktivaĵoj",
    "Notifications" : "Atentigoj",
    "This application enables people to view a log of activities about them, their files or other data." : "Tiu ĉi aplikaĵo permesas al homoj vidi protokolon de aktivecoj pri ili, iliaj dosieroj aŭ aliaj datumoj.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Tiu programo permesas al homoj vidi agojn ligitajn al iliaj dosieroj kaj datenoj en Nextcloud.\n\t\tĈiu persono povas agordi siajn individuajn agadajn agordojn en la personaj agordoj,\n\t\tpor elekti, kian agadon oni devas puŝi al poŝtelefonoj, senditaj per retpoŝto\n\t\taŭ ĉu ĉiutaga resumo estas sendita ĉiumatene.\n\t\tPli detalaj informoj troveblas en Aktivaĵo dokumentado.",
    "Activity notification configuration" : "Agordoj de aktivaĵaj atentigoj",
    "Send email" : "Sendi retpoŝtmesaĝon",
    "Send push notification" : "Sendi puŝan atentigon",
    "Today" : "Hodiaŭ",
    "Yesterday" : "Hieraŭ",
    "You need to set up your email address before you can receive notification emails." : "Vi bezonas agordi vian retpoŝtadreson por povi ricevi sciigojn retmesaĝe.",
    "Send activity emails" : "Sendi aktivaĵajn retmesaĝojn",
    "As soon as possible" : "Kiel eble plej baldaŭ",
    "Hourly" : "Ĉiuhore",
    "Daily" : "Ĉiutage",
    "Weekly" : "Ĉiusemajne",
    "You commented" : "Vi komentis",
    "Message deleted by author" : "Mesaĝo estas forigita per aǔtoro",
    "Open {filename}" : "Malfermi {filename}",
    "in {path}" : "ene de {path}",
    "Home" : "Hejmo",
    "Loading activities" : "Ŝargante aktivaĵojn",
    "This stream will show events like additions, changes & shares" : "Tiu ĉi fluo montros eventojn kiel aldonojn, ŝanĝojn kaj kunhavigojn",
    "No activity yet" : "Ankoraŭ neniu aktivaĵo",
    "Loading more activities" : "Ŝargante pli da aktivaĵojn",
    "No more activities." : "Ne estas pli da aktivecoj",
    "Activity settings" : "Agordoj de aktivaĵoj",
    "Enable RSS feed" : "Aktivigi RSS-fluon",
    "RSS feed" : "RSS-a fluo",
    "Copy RSS feed link" : "Kopii RSS-fluan ligilon",
    "Personal notification settings" : "Agordoj de persona sciigo",
    "RSS link copied to clipboard" : "RSS ligilo estas kopiita en tondujo",
    "Unable to load the activity list" : "Ne eblis ŝargi la liston de aktivaĵoj",
    "Notification" : "Atentigo",
    "Enable notification emails" : "Ebligi atentigajn retmesaĝojn",
    "Choose for which activities you want to get an email or push notification." : "Elektu por kiuj aktivaĵoj vi volas ricevi retpoŝton aŭ puŝan sciigon.",
    "Choose for which activities you want to get a push notification." : "Elektu por kiuj aktivaĵoj vi volas ricevi puŝan sciigon.",
    "Daily activity summary" : "Ĉiutaga resumo de aktivaĵoj",
    "Send daily activity summary in the morning" : "Sendu ĉiutagajn aktivaĵajn resumojn matene",
    "Default settings" : "Defaŭltaj agordoj",
    "Configure the default notification settings for new accounts." : "Agordi la defaŭltajn sciigajn agordojn por novaj kontoj.",
    "Unable to save the settings" : "Ne eblis konservi la agordojn",
    "No more events to load" : "Ne plu ŝargeblaj eventoj",
    "Copied!" : "Kopiita!",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premi ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C por kopii.",
    "{name} (invisible)" : "{name} (nevidebla)",
    "{name} (restricted)" : "{name} (limigita)",
    "There are no events for this filter" : "Neniu evento kun tiu ĉi filtrilo",
    "Activities" : "Aktivaĵoj",
    "Could not load activites" : "Ne eblas ŝargi aktivaĵojn"
},
"nplurals=2; plural=(n != 1);");
